@@ -8,7 +8,12 @@ import socket
 import json
 
 requests.packages.urllib3.disable_warnings()
-
+requests.packages.urllib3.util.ssl_.DEFAULT_CIPHERS += ':HIGH:!DH:!aNULL'
+try:
+    requests.packages.urllib3.contrib.pyopenssl.util.ssl_.DEFAULT_CIPHERS += ':HIGH:!DH:!aNULL'
+except AttributeError:
+    # no pyopenssl support used / needed / available
+    pass
 
 class Connect:
     # initialize object set system type and build DB connectors as needed
