@@ -82,7 +82,7 @@ class Connect:
             else:
                 send_commands.append(arg)
 
-        if not self.status:
+        if self.status is False:
             try:
                 self.netmiko.establish_connection()
                 self.netmiko.enable()
@@ -131,8 +131,10 @@ class Connect:
                     except Exception as err:
                         print(f"Error sending commands: {err}", file=sys.stderr)
                         output.append(False)
-
-            return output
+            if len(output) == 1:
+                return output[0]
+            else:
+                return output
 
         else:
             return False
@@ -166,7 +168,7 @@ class Connect:
                     send_commands.append(each)
             else:
                 send_commands.append(arg)
-        if not self.status:
+        if self.status is False:
             try:
                 self.netmiko.establish_connection()
                 self.netmiko.enable()
@@ -196,11 +198,9 @@ class Connect:
         self.netmiko.cleanup(command='exit')
         return True
 
-    # Keepalive for o365 token in backgroung.  Renew every 10min before expures timer
     def session_keepalive(self):
         while True and self.keep_system_alive:
             time.sleep(30)
-
             # get prompt place to keep session alive
             try:
                 self.netmiko.find_prompt()
@@ -218,7 +218,7 @@ class Connect:
             if self.config:
                 config = self.config
             else:
-                self.config = self.fix_file_format(self.running_config()[0])
+                self.config = self.fix_file_format(self.running_config())
                 config = self.config
         x = 0
         while x < len(config):
@@ -258,7 +258,7 @@ class Connect:
             if self.inventory:
                 return self.inventory
             else:
-                config = self.fix_file_format(self.exec("show inventory")[0])
+                config = self.fix_file_format(self.exec("show inventory"))
                 self.inventory = []
         # Parse show inventory output
         x = 0
@@ -292,7 +292,7 @@ class Connect:
         if config:
             config = self.fix_file_format(config)
         else:
-            config = self.exec("show version")[0].split("\n")
+            config = self.exec("show version").split("\n")
         x = -1
         while x < len(config):
             x += 1
@@ -306,7 +306,7 @@ class Connect:
         if config:
             config = self.fix_file_format(config)
         else:
-            config = self.exec("show cdp neighbor detail")[0].split("\n")
+            config = self.exec("show cdp neighbor detail").split("\n")
         x = 0
         cdp_neighbor = {}
         while x < len(config[x]):
@@ -391,7 +391,10 @@ class Connect:
             return []
 
     def section(self, search, file=None):
-        file_lines = self.fix_file_format(file)
+        if file is None:
+            file_lines = self.config
+        else:
+            file_lines = self.fix_file_format(file)
         return_string = ""
         i = 0
         while i < len(file_lines):
@@ -411,8 +414,12 @@ class Connect:
         return return_string
 
     def include(self, search, file=None):
+        if file is None:
+            file = self.config
+        else:
+            file = self.fix_file_format(file)
         return_string = ""
-        for line in self.fix_file_format(file):
+        for line in file:
             if line.lower().find(search.lower()) > -1:
                 return_string += line
                 return_string += "\n"
